configurationtools.get_abjad_startup_string
===========================================

.. autofunction:: abjad.tools.configurationtools.get_abjad_startup_string.get_abjad_startup_string
   :noindex:
